Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(391)

Unified Diff: Source/core/css/DOMWindowCSS.cpp

Issue 100453011: Rename css/CSSParser to css/parser/BisonCSSParser. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/css/CSSValuePool.cpp ('k') | Source/core/css/FontFace.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/DOMWindowCSS.cpp
diff --git a/Source/core/css/DOMWindowCSS.cpp b/Source/core/css/DOMWindowCSS.cpp
index 248ddcc464871af8749ce81494241c7551ae20b3..37da48d1cb441fec82a1b8d9b3a96cea53f936c8 100644
--- a/Source/core/css/DOMWindowCSS.cpp
+++ b/Source/core/css/DOMWindowCSS.cpp
@@ -30,7 +30,7 @@
#include "config.h"
#include "core/css/DOMWindowCSS.h"
-#include "core/css/CSSParser.h"
+#include "core/css/parser/BisonCSSParser.h"
#include "core/css/RuntimeCSSEnabled.h"
#include "core/css/StylePropertySet.h"
#include "wtf/text/WTFString.h"
@@ -65,7 +65,7 @@ bool DOMWindowCSS::supports(const String& property, const String& value) const
if (!RuntimeCSSEnabled::isCSSPropertyEnabled(propertyID))
return false;
// CSSParser::parseValue() won't work correctly if !important is present,
// so just get rid of it. It doesn't matter to supports() if it's actually
// there or not, provided how it's specified in the value is correct.
String normalizedValue = value.stripWhiteSpace().simplifyWhiteSpace();
@@ -75,13 +75,13 @@ bool DOMWindowCSS::supports(const String& property, const String& value) const
return false;
RefPtr<MutableStylePropertySet> dummyStyle = MutableStylePropertySet::create();
- return CSSParser::parseValue(dummyStyle.get(), propertyID, normalizedValue, false, HTMLStandardMode, 0);
+ return BisonCSSParser::parseValue(dummyStyle.get(), propertyID, normalizedValue, false, HTMLStandardMode, 0);
}
bool DOMWindowCSS::supports(const String& conditionText) const
{
CSSParserContext context(HTMLStandardMode);
- CSSParser parser(context);
+ BisonCSSParser parser(context);
return parser.parseSupportsCondition(conditionText);
}
« no previous file with comments | « Source/core/css/CSSValuePool.cpp ('k') | Source/core/css/FontFace.cpp » ('j') | no next file with comments »
@@ -65,7 +65,7 @@ bool DOMWindowCSS::supports(const String& property, const String& value) const
if (!RuntimeCSSEnabled::isCSSPropertyEnabled(propertyID))
return false;
- // CSSParser::parseValue() won't work correctly if !important is present,
+ // BisonCSSParser::parseValue() won't work correctly if !important is present,
// so just get rid of it. It doesn't matter to supports() if it's actually
// there or not, provided how it's specified in the value is correct.

Powered by Google App Engine
This is Rietveld 408576698